@@ -2,6 +2,8 @@ CONFIG_DRUPAL_URL = "ckanext.drupal_api.drupal_url"
 
 CONFIG_CACHE_DURATION = "ckanext.drupal_api.cache.duration"
 CONFIG_REQUEST_TIMEOUT = "ckanext.drupal_api.timeout"
+CONFIG_REQUEST_HTTP_USER = "ckanext.drupal_api.request.user"
+CONFIG_REQUEST_HTTP_PASS = "ckanext.drupal_api.request.pass"
 
 CONFIG_DRUPAL_API_VERSION = "ckanext.drupal_api.api_version"
 JSON_API = "json"
